===========
Grid reader
===========

Sub-commands to support file reading. These are in technically components in that they
render a full command line however they are not intended to be used directly but rather
as sub-components of CGRID and INPGRID commands.

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.subcomponents.readgrid.GRIDREGULAR
   rompy_swan.subcomponents.readgrid.READCOORD
   rompy_swan.subcomponents.readgrid.READINP
